Crate plottery_project

Crate plottery_project 

Plottery project

This library contains all necessary functionality to create and manage a Plottery project.

A Plottery project is a wrapper around a cargo package:

folder structure

Modules

curve_2d
curve_2d_norm
project_param
project_param_value
project_params_definition
project_params_list_wrapper

Structs

Curve2D
A 2D curve with domain mapping.
Curve2DNorm
A normalized 2D curve for transfer functions and easing curves.
Domain
A 2D domain defining x and y ranges.
Project
ProjectConfig
ProjectParam
ProjectParamsListWrapper

Enums

LibSource
ProjectParamValue

Traits

PlotteryParams

Functions

build_cargo_project_async
export_plottery_home
generate_cargo_project_to_disk
init_git_repo
process_stderr_lines
process_stdout_lines
read_object_from_stdout
read_stdout_as_string_to_end
run_project
run_project_executable_async

Derive Macros

PlotteryParams