pub struct Curve2DNorm { /* private fields */ }Expand description
A normalized 2D curve for transfer functions and easing curves.
Both x and y values are in the range [0.0, 1.0].
Usage
Use sample(x) to get the y-value at any x position:
use plottery_project::Curve2DNorm;
let curve = Curve2DNorm::default();
let y = curve.sample(0.5);Implementations
Sourceimpl Curve2DNorm
impl Curve2DNorm
pub fn new(y_first: f32, points: Vec<V2>, y_last: f32) -> Self
pub fn iter_points(&self) -> impl Iterator<Item = V2> + '_
pub fn len(&self) -> usize
Sourcepub fn sample(&self, x: f32) -> f32
pub fn sample(&self, x: f32) -> f32
Sample the curve at position x.
Returns the y-value at the given x position using linear interpolation. Input x is clamped to [0.0, 1.0].
pub fn add_point(&mut self, point: V2) -> Result<()>
pub fn remove_point_at(&mut self, index: usize) -> Result<()>
pub fn update_endpoint(&mut self, is_first: bool, y: f32)
pub fn update_point_y_norm(&mut self, index: usize, y: f32) -> Result<()>
pub fn update_point_norm( &mut self, index: usize, new_loc_norm: V2, ) -> Result<()>