Plottery project
This library contains all necessary functionality to create and manage a Plottery project.
A Plottery project is a wrapper around a cargo package:
Modules
- curve_
2d - curve_
2d_ norm - project_
param - project_
param_ value - project_
params_ definition - project_
params_ list_ wrapper
Structs
- Curve2D
- A 2D curve with domain mapping.
- Curve2D
Norm - A normalized 2D curve for transfer functions and easing curves.
- Domain
- A 2D domain defining x and y ranges.
- Project
- Project
Config - Project
Param - Project
Params List Wrapper
Enums
Traits
Functions
- build_
cargo_ project_ async - export_
plottery_ home - generate_
cargo_ project_ to_ disk - init_
git_ repo - process_
stderr_ lines - process_
stdout_ lines - read_
object_ from_ stdout - read_
stdout_ as_ string_ to_ end - run_
project - run_
project_ executable_ async